==> dxde_1.40.6-1.tar.gz: BUILD/src/model/data/firma.cpp <==
/***************************************************************
 * Name:      firma.cpp
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2014
 * License:   GPL3
 **************************************************************/

#include "firma.h"

Firma::Firma(const wxString &nazev, const wxString &ic, const wxString &dic, const wxString &registrace, bool platce, bool pausal,
             const wxString &telefon, const wxString &email, const wxString &www, const wxString &logo,
             const wxString &razitko, int adresaid, bool eet)
    : m_nazev(nazev), m_ic(ic), m_dic(dic), m_registrace(registrace), m_platce(platce), m_pausal(pausal),
      m_telefon(telefon), m_email(email), m_www(www), m_logo(logo), m_razitko(razitko), m_adresaid(adresaid), m_eet(eet)
{
}

bool Firma::isValid() const
{
    return !m_nazev.IsEmpty();
}

wxString Firma::nazev() const
{
    return m_nazev;
}

void Firma::setNazev(const wxString &nazev)
{
    m_nazev = nazev;
}

wxString Firma::ic() const
{
    return m_ic;
}

void Firma::setIc(const wxString &ic)
{
    m_ic = ic;
}

wxString Firma::dic() const
{
    return m_dic;
}

void Firma::setDic(const wxString &dic)
{
    m_dic = dic;
}

wxString Firma::registrace() const
{
    return m_registrace;
}

void Firma::setRegistrace(const wxString &registrace)
{
    m_registrace = registrace;
}

bool Firma::platce() const
{
    return m_platce;
}

void Firma::setPlatce(bool platce)
{
    m_platce = platce;
}

wxString Firma::telefon() const
{
    return m_telefon;
}

void Firma::setTelefon(const wxString &telefon)
{
    m_telefon = telefon;
}

wxString Firma::email() const
{
    return m_email;
}

void Firma::setEmail(const wxString &email)
{
    m_email = email;
}

wxString Firma::www() const
{
    return m_www;
}

void Firma::setWww(const wxString &www)
{
    m_www = www;
}

wxString Firma::logo() const
{
    return m_logo;
}

void Firma::setLogo(const wxString &logo)
{
    m_logo = logo;
}

wxString Firma::razitko() const
{
    return m_razitko;
}

void Firma::setRazitko(const wxString &razitko)
{
    m_razitko = razitko;
}

int Firma::adresaid() const
{
    return m_adresaid;
}

void Firma::setAdresaid(int adresaid)
{
    m_adresaid = adresaid;
}

bool Firma::pausal() const
{
    return m_pausal;
}

void Firma::setPausal(bool pausal)
{
    m_pausal = pausal;
}

bool Firma::eet() const
{
    return m_eet;
}

void Firma::setEet(bool eet)
{
    m_eet = eet;
}

==> dxde_1.40.12-1.tar.gz: BUILD/src/model/data/firma.cpp <==
/***************************************************************
 * Name:      firma.cpp
 * Author:    David Vachulka (archdvx@dxsolutions.org)
 * Copyright: 2014
 * License:   GPL3
 **************************************************************/

#include "firma.h"

Firma::Firma(const wxString &nazev, const wxString &ic, const wxString &dic, const wxString &registrace, bool platce, bool pausal,
             const wxString &telefon, const wxString &email, const wxString &www, const wxString &logo,
             const wxString &razitko, int adresaid)
    : m_nazev(nazev), m_ic(ic), m_dic(dic), m_registrace(registrace), m_platce(platce), m_pausal(pausal),
      m_telefon(telefon), m_email(email), m_www(www), m_logo(logo), m_razitko(razitko), m_adresaid(adresaid)
{
}

bool Firma::isValid() const
{
    return !m_nazev.IsEmpty();
}

wxString Firma::nazev() const
{
    return m_nazev;
}

void Firma::setNazev(const wxString &nazev)
{
    m_nazev = nazev;
}

wxString Firma::ic() const
{
    return m_ic;
}

void Firma::setIc(const wxString &ic)
{
    m_ic = ic;
}

wxString Firma::dic() const
{
    return m_dic;
}

void Firma::setDic(const wxString &dic)
{
    m_dic = dic;
}

wxString Firma::registrace() const
{
    return m_registrace;
}

void Firma::setRegistrace(const wxString &registrace)
{
    m_registrace = registrace;
}

bool Firma::platce() const
{
    return m_platce;
}

void Firma::setPlatce(bool platce)
{
    m_platce = platce;
}

wxString Firma::telefon() const
{
    return m_telefon;
}

void Firma::setTelefon(const wxString &telefon)
{
    m_telefon = telefon;
}

wxString Firma::email() const
{
    return m_email;
}

void Firma::setEmail(const wxString &email)
{
    m_email = email;
}

wxString Firma::www() const
{
    return m_www;
}

void Firma::setWww(const wxString &www)
{
    m_www = www;
}

wxString Firma::logo() const
{
    return m_logo;
}

void Firma::setLogo(const wxString &logo)
{
    m_logo = logo;
}

wxString Firma::razitko() const
{
    return m_razitko;
}

void Firma::setRazitko(const wxString &razitko)
{
    m_razitko = razitko;
}

int Firma::adresaid() const
{
    return m_adresaid;
}

void Firma::setAdresaid(int adresaid)
{
    m_adresaid = adresaid;
}

bool Firma::pausal() const
{
    return m_pausal;
}

void Firma::setPausal(bool pausal)
{
    m_pausal = pausal;
}
